@@ -1,13 +1,11 @@
 /* signals.c -- install and maintain signal handlers.
-   $Id: signals.c,v 1.7.2.1 2007/06/27 17:10:59 karl Exp $
 
-   Copyright (C) 1993, 1994, 1995, 1998, 2002, 2003, 2004, 2007 Free Software
-   Foundation, Inc.
+   Copyright 1993-2019 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3, or (at your option)
-   any later version.
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,12 +13,14 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-   Originally written by Brian Fox (bfox@ai.mit.edu). */
+   Originally written by Brian Fox. */
 
 #include "info.h"
+#include "display.h"
+#include "footnotes.h"
+#include "window.h"
 #include "signals.h"
 
 void initialize_info_signal_handler (void);
@@ -81,6 +81,9 @@ mask_termsig (sigset_t *set)
 #if defined (SIGINT)
   sigaddset (set, SIGINT);
 #endif
+#if defined (SIGTERM)
+  sigaddset (set, SIGTERM);
+#endif
 # if defined (SIGUSR1)
   sigaddset (set, SIGUSR1);
 # endif
@@ -112,7 +115,7 @@ static int term_conf_busy = 0;
 #endif /* !HAVE_SIGACTION */
 
 static signal_info old_TSTP, old_TTOU, old_TTIN;
-static signal_info old_WINCH, old_INT, old_USR1;
+static signal_info old_WINCH, old_INT, old_TERM, old_USR1;
 static signal_info old_QUIT;
 
 void
@@ -146,36 +149,61 @@ initialize_info_signal_handler (void)
   set_termsig (SIGINT, &old_INT);
 #endif
 
+#if defined (SIGTERM)
+  set_termsig (SIGTERM, &old_TERM);
+#endif
+
 #if defined (SIGUSR1)
   /* Used by DJGPP to simulate SIGTSTP on Ctrl-Z.  */
   set_termsig (SIGUSR1, &old_USR1);
 #endif
 }
 
-static void
+void
 redisplay_after_signal (void)
 {
   terminal_clear_screen ();
   display_clear_display (the_display);
+  if (auto_footnotes_p)
+    info_get_or_remove_footnotes (active_window);
   window_mark_chain (windows, W_UpdateWindow);
-  display_update_display (windows);
+  display_update_display ();
   display_cursor_at_point (active_window);
   fflush (stdout);
 }
 
-static void
+void
 reset_info_window_sizes (void)
 {
-  terminal_goto_xy (0, 0);
-  fflush (stdout);
-  terminal_unprep_terminal ();
   terminal_get_screen_size ();
-  terminal_prep_terminal ();
   display_initialize_display (screenwidth, screenheight);
   window_new_screen_size (screenwidth, screenheight);
   redisplay_after_signal ();
 }
 
+/* Number of times we were told to ignore SIGWINCH. */
+static int sigwinch_block_count = 0;
+
+void
+signal_block_winch (void)
+{
+#if defined (SIGWINCH)
+  if (sigwinch_block_count == 0)
+    BLOCK_SIGNAL (SIGWINCH);
+  sigwinch_block_count++;
+#endif
+}
+
+void
+signal_unblock_winch (void)
+{
+#if defined (SIGWINCH)
+  sigwinch_block_count--;
+  if (sigwinch_block_count == 0)
+    UNBLOCK_SIGNAL (SIGWINCH);
+#endif
+}
+
 static RETSIGTYPE
 info_signal_proc (int sig)
 {
@@ -207,6 +235,9 @@ info_signal_proc (int sig)
 #endif
 #if defined (SIGINT)
     case SIGINT:
+#endif
+#if defined (SIGTERM)
+    case SIGTERM:
 #endif
       {
 #if defined (SIGTSTP)
@@ -225,6 +256,10 @@ info_signal_proc (int sig)
         if (sig == SIGINT)
           old_signal_handler = &old_INT;
 #endif /* SIGINT */
+#if defined (SIGTERM)
+        if (sig == SIGTERM)
+          old_signal_handler = &old_TERM;
+#endif /* SIGTERM */
 
         /* For stop signals, restore the terminal IO, leave the cursor
            at the bottom of the window, and stop us. */
@@ -264,17 +299,30 @@ info_signal_proc (int sig)
 	if (sig == SIGUSR1)
 	  old_signal_handler = &old_USR1;
 #endif
-	terminal_goto_xy (0, 0);
-	fflush (stdout);
-	terminal_unprep_terminal (); /* needless? */
+
+        /* This seems risky: what if we receive a (real) signal before
+           the next line is reached? */
+#if 0
 	restore_termsig (sig, old_signal_handler);
-	UNBLOCK_SIGNAL (sig);
 	kill (getpid (), sig);
+#endif
 
 	/* After our old signal handler returns... */
 	set_termsig (sig, old_signal_handler); /* needless? */
-	terminal_prep_terminal ();
+
+        if (sigwinch_block_count != 0)
+          abort ();
+
+        /* Avoid any of the code unblocking the signal too early.  This
+           should set the variable to 1 because we shouldn't be here if
+           sigwinch_block_count > 0. */
+        sigwinch_block_count++;
+
 	reset_info_window_sizes ();
+
+        sigwinch_block_count--;
+        /* Don't unblock the signal until after we've finished. */
+	UNBLOCK_SIGNAL (sig);
       }
       break;
 #endif /* SIGWINCH || SIGUSR1 */
@@ -292,4 +340,6 @@ info_signal_proc (int sig)
 #endif /* HAVE_SIGPROCMASK || HAVE_SIGSETMASK */
 #endif /* !HAVE_SIGACTION */
 }
+
+
 /* vim: set sw=2 cino={1s>2sn-s^-se-s: */
