@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright (C) 2015 Free Software Foundation, Inc.
+# Copyright (C) 2015-2018 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,15 +16,14 @@
 
 srcdir=${srcdir:-.}
 . $srcdir/t/Init-test.inc
-. $t/Init-inter.inc
 
 # Follow a dir entry to a file in a subdirectory of infodir
 run_ginfo subdir
-printf 'Dq' >$PTY_TYPE
-. $t/Timeout-test.inc
+printf 'Dq' >$pty_type
+timeout_test
 
-cat $GINFO_OUTPUT
-grep '^File: file-in-subdir.info' $GINFO_OUTPUT
-RETVAL=$?
+cat $ginfo_output
+grep '^File: file-in-subdir.info' $ginfo_output
+retval=$?
 
 cleanup
