@@ -1,8 +1,6 @@
 /* termdep.h -- system things that terminal.c depends on.
-   $Id: termdep.h 5337 2013-08-22 17:54:06Z karl $
 
-   Copyright 1993, 1996, 1997, 1998, 2001, 2002, 2007, 2012, 2013
-   Free Software Foundation, Inc.
+   Copyright 1993-2019 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -49,7 +47,7 @@
 #  endif /* !HAVE_TERMIO_H */
 #endif /* !HAVE_TERMIOS_H */
 
-#ifdef GWINSZ_IN_SYS_IOCTL
+#ifdef HAVE_SYS_IOCTL_H
 #  include <sys/ioctl.h>
 #endif
 
