@@ -1,9 +1,6 @@
 /* terminal.c -- how to handle the physical terminal for Info.
-   $Id: terminal.c 6914 2016-01-02 17:36:03Z gavin $
 
-   Copyright 1988, 1989, 1990, 1991, 1992, 1993, 1996, 1997, 1998,
-   1999, 2001, 2002, 2004, 2007, 2008, 2012, 2013, 2014, 2015
-   Free Software Foundation, Inc.
+   Copyright 1988-2019 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,13 +27,13 @@
 #include <signal.h>
 
 /* The Unix termcap interface code. */
-/* With MinGW, if the user has ncurses installed, including
-   ncurses/termcap.h will cause the Info binary depend on the ncurses
+/* With MinGW, if the user has ncurses installed, including termcap.h
+   or ncurses/termcap.h will cause the Info binary depend on the ncurses
    DLL, just because BC and PC are declared there, although they are
    never used in the MinGW build.  Avoid that useless dependency.  */
 #if defined (HAVE_NCURSES_TERMCAP_H) && !defined (__MINGW32__)
 #include <ncurses/termcap.h>
-#elif defined (HAVE_TERMCAP_H)
+#elif defined (HAVE_TERMCAP_H) && !defined (__MINGW32__)
 #include <termcap.h>
 #else  /* (!HAVE_NCURSES_TERMCAP_H || __MINGW32__) && !HAVE_TERMCAP_H */
 /* On Solaris2, sys/types.h #includes sys/reg.h, which #defines PC.
@@ -454,7 +451,7 @@ void
 terminal_begin_blink (void)
 {
   if (terminal_begin_blink_hook)
-    (*terminal_begin_underline_hook) ();
+    (*terminal_begin_blink_hook) ();
   else
     {
       send_to_terminal (term_mb);
@@ -648,16 +645,16 @@ terminal_switch_rendition (unsigned long new)
       terminal_end_all_modes ();
       old = 0;
     }
+  else if (!(new & COLOUR_MASK) && (old & COLOUR_MASK)
+           || !(new & BGCOLOUR_MASK) && (old & BGCOLOUR_MASK))
+    {
+      terminal_default_colour ();
+      old &= ~(COLOUR_MASK|BGCOLOUR_MASK);
+    }
 
   if ((new & COLOUR_MASK) != (old & COLOUR_MASK))
     {
-      /* Switch colour. */
-      if ((new & COLOUR_MASK) == 00)
-        {
-          terminal_default_colour ();
-          old &= ~BGCOLOUR_MASK;
-        }
-      else if ((new & COLOUR_MASK) >= 8)
+      if ((new & COLOUR_MASK) >= 8)
         {
           terminal_set_colour ((new & COLOUR_MASK) - 8);
         }
@@ -666,16 +663,13 @@ terminal_switch_rendition (unsigned long new)
   if ((new & BGCOLOUR_MASK) != (old & BGCOLOUR_MASK))
     {
       /* Switch colour. */
-      if ((new & BGCOLOUR_MASK) == 00)
-        {
-          terminal_default_colour ();
-        }
-      else if ((new & BGCOLOUR_MASK) >> 9 >= 8)
+      if ((new & BGCOLOUR_MASK) >> 9 >= 8)
         {
           terminal_set_bgcolour (((new & BGCOLOUR_MASK) >> 9) - 8);
         }
       /* Colour values from 1 to 7 don't do anything right now. */
     }
+
   if ((new & UNDERLINE_MASK) != (old & UNDERLINE_MASK))
     {
       if ((new & UNDERLINE_MASK))
