@@ -1,9 +1,6 @@
 /* install-info -- merge Info directory entries from an Info file.
-   $Id: install-info.c 5313 2013-08-15 16:07:06Z karl $
 
-   Copyright 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
-   2005, 2007, 2008, 2009, 2010, 2011, 2012, 2013
-   Free Software Foundation, Inc.
+   Copyright 1996-2019 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,6 +23,7 @@
 #define TAB_WIDTH 8
 
 static char *progname = "install-info";
+static char *default_section = NULL;
 
 struct spec_entry;
 struct spec_section;
@@ -146,6 +144,8 @@ struct option longopts[] =
   { "calign",    required_argument, NULL, 'C'},
   { "debug",     no_argument, NULL, 'g' },
   { "delete",    no_argument, NULL, 'r' },
+  { "defentry",  required_argument, NULL, 'E' },
+  { "defsection",  required_argument, NULL, 'S' },
   { "dir-file",  required_argument, NULL, 'd' },
   { "entry",     required_argument, NULL, 'e' },
   { "name",      required_argument, NULL, 't' },
@@ -283,6 +283,11 @@ copy_string (const char *string, int size)
 void
 pfatal_with_name (const char *name)
 {
+  /* Empty files don't set errno, so we get something like
+     "install-info: No error for foo", which is confusing.  */
+  if (errno == 0)
+    fatal (_("%s: empty file"), name);
+
   fatal (_("%s for %s"), strerror (errno), name);
 }
 
@@ -548,6 +553,8 @@ Options:\n\
  --debug             report what is being done.\n\
  --delete            delete existing entries for INFO-FILE from DIR-FILE;\n\
                       don't insert any new entries.\n\
+ --defsection=TEXT   like --section, but only use TEXT if no sections\n\
+                      are present in INFO-FILE (replacing \"Miscellaneous\").\n\
  --description=TEXT  the description of the entry is TEXT; used with\n\
                       the --name option to become synonymous with the\n\
                       --entry option.\n\
@@ -590,7 +597,10 @@ Options:\n\
                       If you specify more than one section, all the entries\n\
                        are added in each of the sections.\n\
                       If you don't specify any sections, they are determined\n\
-                       from information in the Info file itself.\n\
+                       from information in the Info file itself;\n\
+                       if nothing is available there, the --defsection\n\
+                       value is used; if that is not specified, the\n\
+                       final default is \"Miscellaneous\".\n\
  --section R SEC     equivalent to --regex=R --section=SEC --add-once."));
 
   puts (_("\
@@ -623,7 +633,6 @@ ensure_dirfile_exists (char *dirfile)
     {
       FILE *f;
       char *readerr = strerror (errno);
-      close (desc);
       f = fopen (dirfile, "w");
       if (f)
         {
@@ -634,7 +643,7 @@ The first time you invoke Info you start off looking at this node.\n\
 %s\tThis is the top of the INFO tree\n\
 \n\
   This (the Directory node) gives a menu of major topics.\n\
-  Typing \"q\" exits, \"?\" lists all Info commands, \"d\" returns here,\n\
+  Typing \"q\" exits, \"H\" lists all Info commands, \"d\" returns here,\n\
   \"h\" gives a primer for first-timers,\n\
   \"mEmacs<Return>\" visits the Emacs manual, etc.\n\
 \n\
@@ -658,22 +667,24 @@ The first time you invoke Info you start off looking at this node.\n\
   else
     close (desc); /* It already existed, so fine.  */
 }
+
 
 /* Open FILENAME and return the resulting stream pointer.  If it doesn't
    exist, try FILENAME.gz.  If that doesn't exist either, call
    CREATE_CALLBACK (with FILENAME as arg) to create it, if that is
-   non-NULL.  If still no luck, fatal error.
+   non-NULL.  If still no luck, return a null pointer.
 
-   If we do open it, return the actual name of the file opened in
-   OPENED_FILENAME and the compress program to use to (de)compress it in
+   Return the actual name of the file we tried to open in
+   OPENED_FILENAME and the compress program to (de)compress it in
    COMPRESSION_PROGRAM.  The compression program is determined by the
+   magic number, not the filename.
    
-   MAGIC number, not the filename.  */
-
+   Return either stdin reading the file, or a non-stdin pipe reading
+   the output of the compression program.  */
 FILE *
 open_possibly_compressed_file (char *filename,
     void (*create_callback) (char *),
-    char **opened_filename, char **compression_program, int *is_pipe) 
+    char **opened_filename, char **compression_program) 
 {
   char *local_opened_filename, *local_compression_program;
   int nread;
@@ -730,35 +741,58 @@ open_possibly_compressed_file (char *filename,
       f = fopen (*opened_filename, FOPEN_RBIN);
     }
 #endif /* __MSDOS__ */
-   if (!f)
-     {
-       if (create_callback)
-         { /* That didn't work either.  Create the file if we can.  */
-           (*create_callback) (filename);
+  if (!f)
+    {
+      /* The file was not found with any extention added.  Try the
+         original file again. */
+      free (*opened_filename);
+      *opened_filename = filename;
 
-           /* And try opening it again.  */
-           free (*opened_filename);
-           *opened_filename = filename;
-           f = fopen (*opened_filename, FOPEN_RBIN);
-           if (!f)
-             pfatal_with_name (filename);
-         }
-       else
-         pfatal_with_name (filename);
-     }
+      if (create_callback)
+        {
+          /* Create the file if we can.  */
+          (*create_callback) (filename);
+
+          /* And try opening it again.  */
+          f = fopen (*opened_filename, FOPEN_RBIN);
+          if (!f)
+            return 0;
+        }
+      else
+        return 0;
+    }
 
   /* Read first few bytes of file rather than relying on the filename.
      If the file is shorter than this it can't be usable anyway.  */
   nread = fread (data, sizeof (data), 1, f);
   if (nread != 1)
     {
-      /* Empty files don't set errno, so we get something like
-         "install-info: No error for foo", which is confusing.  */
       if (nread == 0)
-        fatal (_("%s: empty file"), *opened_filename);
-      pfatal_with_name (*opened_filename);
+        {
+          /* Try to create the file if its empty. */
+          if (feof (f) && create_callback)
+            {
+              if (fclose (f) != 0)
+                return 0; /* unknown error closing file */
+
+              if (remove (filename) != 0)
+                return 0; /* unknown error deleting file */
+
+              (*create_callback) (filename);
+              f = fopen (*opened_filename, FOPEN_RBIN);
+              if (!f)
+                return 0;
+              nread = fread (data, sizeof (data), 1, f);
+              if (nread == 0)
+                return 0;
+              goto determine_file_type; /* success */
+            }
+        }
+      errno = 0;
+      return 0; /* unknown error */
     }
 
+determine_file_type:
   if (!compression_program)
     compression_program = &local_compression_program;
 
@@ -819,27 +853,36 @@ open_possibly_compressed_file (char *filename,
   else
     *compression_program = NULL;
 
+  /* Seek back over the magic bytes.  */
+  if (fseek (f, 0, 0) < 0)
+    return 0;
+
   if (*compression_program)
-    { /* It's compressed, so fclose the file and then open a pipe.  */
-      char *command = concat (*compression_program," -cd <", *opened_filename);
+    { /* It's compressed, so open a pipe.  */
+      char *command = concat (*compression_program, " -d", "");
+
       if (fclose (f) < 0)
-        pfatal_with_name (*opened_filename);
+        return 0;
+      f = freopen (*opened_filename, FOPEN_RBIN, stdin);
+      if (!f)
+        return 0;
       f = popen (command, "r");
-      if (f)
-        *is_pipe = 1;
-      else
-        pfatal_with_name (command);
+      if (!f)
+        {
+          /* Used for error message in calling code. */
+          *opened_filename = command;
+          return 0;
+        }
     }
   else
-    { /* It's a plain file, seek back over the magic bytes.  */
-      if (fseek (f, 0, 0) < 0)
-        pfatal_with_name (*opened_filename);
+    {
 #if O_BINARY
       /* Since this is a text file, and we opened it in binary mode,
          switch back to text mode.  */
       f = freopen (*opened_filename, "r", f);
+      if (! f)
+	return 0;
 #endif
-      *is_pipe = 0;
     }
 
   return f;
@@ -850,32 +893,32 @@ open_possibly_compressed_file (char *filename,
    (i.e., try FILENAME.gz et al. if FILENAME does not exist) and store
    the actual file name that was opened into OPENED_FILENAME (if it is
    non-NULL), and the companion compression program (if any, else NULL)
-   into COMPRESSION_PROGRAM (if that is non-NULL).  If trouble, do
-   a fatal error.  */
+   into COMPRESSION_PROGRAM (if that is non-NULL).  If trouble, return
+   a null pointer. */
 
 char *
 readfile (char *filename, int *sizep,
     void (*create_callback) (char *), char **opened_filename,
     char **compression_program)
 {
-  char *real_name;
   FILE *f;
-  int pipe_p;
   int filled = 0;
   int data_size = 8192;
   char *data = xmalloc (data_size);
 
   /* If they passed the space for the file name to return, use it.  */
   f = open_possibly_compressed_file (filename, create_callback,
-                                     opened_filename ? opened_filename
-                                                     : &real_name,
-                                     compression_program, &pipe_p);
+                                     opened_filename,
+                                     compression_program);
+
+  if (!f)
+    return 0;
 
   for (;;)
     {
       int nread = fread (data + filled, 1, data_size - filled, f);
       if (nread < 0)
-        pfatal_with_name (real_name);
+        return 0;
       if (nread == 0)
         break;
 
@@ -892,10 +935,8 @@ readfile (char *filename, int *sizep,
   /* We need to close the stream, since on some systems the pipe created
      by popen is simulated by a temporary file which only gets removed
      inside pclose.  */
-  if (pipe_p)
+  if (f != stdin)
     pclose (f);
-  else
-    fclose (f);
 
   *sizep = filled;
   return data;
@@ -1038,8 +1079,13 @@ output_dirfile (char *dirfile, int dir_nlines, struct line_data *dir_lines,
     fclose (output);
 }
 
-/* Parse the input to find the section names and the entry names it
-   specifies.  Return the number of entries to add from this file.  */
+/* Read through the input LINES, to find the section names and the
+   entry names it specifies. Each INFO-DIR-SECTION entry is added
+   to the SECTIONS linked list.  Each START-INFO-DIR-ENTRY block is added to 
+   the ENTRIES linked list, and the last group of INFO-DIR-SECTION entries
+   is recorded in next->entry_sections and next->entry_sections_tail, where
+   next is the new entry.  Return the number of entries to add from this 
+   file.  */
 int
 parse_input (const struct line_data *lines, int nlines,
              struct spec_section **sections, struct spec_entry **entries,
@@ -1058,12 +1104,6 @@ parse_input (const struct line_data *lines, int nlines,
   if (ignore_sections && ignore_entries)
     return 0;
 
-  /* Loop here processing lines from the input file.  Each
-     INFO-DIR-SECTION entry is added to the SECTIONS linked list.
-     Each START-INFO-DIR-ENTRY block is added to the ENTRIES linked
-     list, and all its entries inherit the chain of SECTION entries
-     defined by the last group of INFO-DIR-SECTION entries we have
-     seen until that point.  */
   for (i = 0; i < nlines; i++)
     {
       if (!ignore_sections
@@ -1105,6 +1145,8 @@ parse_input (const struct line_data *lines, int nlines,
                  tail pointer.  */
               reset_tail = 1;
 
+              /* Save start of the entry.  If this is non-zero, we're
+                 already inside an entry, so fail. */
               if (start_of_this_entry != 0)
                 fatal (_("START-INFO-DIR-ENTRY without matching END-INFO-DIR-ENTRY"));
               start_of_this_entry = lines[i + 1].start;
@@ -1117,9 +1159,8 @@ parse_input (const struct line_data *lines, int nlines,
                                 lines[i].start, lines[i].size)
                       && sizeof ("END-INFO-DIR-ENTRY") - 1 == lines[i].size))
                 {
-                  /* We found an end of this entry.  Allocate another
-                     entry, fill its data, and add it to the linked
-                     list.  */
+                  /* We found the end of this entry.  Save its contents
+                     in a new entry in the linked list.  */
                   struct spec_entry *next
                     = (struct spec_entry *) xmalloc (sizeof (struct spec_entry));
                   next->text
@@ -1128,6 +1169,7 @@ parse_input (const struct line_data *lines, int nlines,
                   next->text_len = lines[i].start - start_of_this_entry;
                   next->entry_sections = head;
                   next->entry_sections_tail = tail;
+                  next->missing_basename = 0;
                   next->next = *entries;
                   *entries = next;
                   n_entries++;
@@ -1354,33 +1396,36 @@ adjust_column (size_t column, char c)
   return column;
 }
 
-/* Indent the Info entry's NAME and DESCRIPTION.  Lines are wrapped at the
-   WIDTH column.  The description on first line is indented at the CALIGN-th 
-   column, and all subsequent lines are indented at the ALIGN-th column.  
-   The resulting Info entry is put into OUTSTR.
+/* Format the Info entry's NAME and DESCRIPTION.
    NAME is of the form "* TEXT (TEXT)[:TEXT].".
+   The description on the first line is indented at the CALIGN-th column, and 
+   all subsequent lines are indented at the ALIGN-th column.
+   Lines are wrapped at the WIDTH column.
+   The resulting Info entry is put into OUTSTR.
  */
 static int
-format_entry (char *name, size_t name_len, char *desc, size_t desc_len, 
-              int calign, int align, size_t width, 
-              char **outstr, size_t *outstr_len)
+format_entry (char *name, size_t name_len, char *desc, size_t desc_len,
+              int calign, int align, size_t width,
+              char **outstr_out, size_t *outstr_len)
 {
   int i, j;
   char c;
   size_t column = 0;            /* Screen column where next char will go */
-  size_t offset_out = 0;        /* Index in `line_out' for next char. */
+
+  /* Used to collect a line at a time, before transferring to outstr. */
   static char *line_out = NULL;
-  static size_t allocated_out = 0;
-  int saved_errno;
+  size_t offset_out = 0;           /* Index in `line_out' for next char. */
+  static size_t allocated_out = 0; /* Space allocated in `line_out'. */
+  char *outstr;
+
   if (!desc || !name)
     return 1;
 
-  *outstr = malloc (width  + 
-                    (((desc_len  + width) / (width - align)) * width) * 2 
-                    * sizeof (char));
-  *outstr[0] = '\0';
+  outstr = xmalloc (width
+         + (desc_len + width) / (width - align) * width * 2 * sizeof (char));
+  outstr[0] = '\0';
 
-  strncat (*outstr, name, name_len);
+  strncat (outstr, name, name_len);
 
   column = name_len;
 
@@ -1389,12 +1434,12 @@ format_entry (char *name, size_t name_len, char *desc, size_t desc_len,
       /* Name is too long to have description on the same line. */
       if (desc_len > 1)
         {
-          strncat (*outstr, "\n", 1);
+          strncat (outstr, "\n", 1);
           column = 0;
           for (j = 0; j < calign - 1; j++)
             {
               column = adjust_column (column, ' ');
-              strncat (*outstr, " ", 1);
+              strncat (outstr, " ", 1);
             }
         }
     }
@@ -1404,7 +1449,7 @@ format_entry (char *name, size_t name_len, char *desc, size_t desc_len,
         if (desc_len <= 2)
           break;
         column = adjust_column (column, ' ');
-        strncat (*outstr, " ", 1);
+        strncat (outstr, " ", 1);
       }
 
   for (i = 0; i < desc_len; i++)
@@ -1415,17 +1460,20 @@ format_entry (char *name, size_t name_len, char *desc, size_t desc_len,
       if (offset_out + 1 >= allocated_out)
         {
           allocated_out = offset_out + 1;
-          line_out = (char *) realloc ((void *)line_out, allocated_out);
+          line_out = (char *) xrealloc ((void *)line_out, allocated_out + 1);
+          /* The + 1 here shouldn't be necessary, but a crash was reported
+             for a following strncat call. */
         }
 
       if (c == '\n')
         {
           line_out[offset_out++] = c;
-          strncat (*outstr, line_out, offset_out);
+          strncat (outstr, line_out, offset_out);
           column = offset_out = 0;
           continue;
         }
 
+      /* Come here from inside "column > width" block below. */
     rescan:
       column = adjust_column (column, c);
 
@@ -1456,12 +1504,12 @@ format_entry (char *name, size_t name_len, char *desc, size_t desc_len,
 
               /* Found a blank.  Don't output the part after it. */
               logical_end++;
-              strncat (*outstr, line_out, logical_end);
-              strncat (*outstr, "\n", 1);
+              strncat (outstr, line_out, logical_end);
+              strncat (outstr, "\n", 1);
               for (j = 0; j < align - 1; j++)
                 {
                   column = adjust_column (column, ' ');
-                  strncat (*outstr, " ", 1);
+                  strncat (outstr, " ", 1);
                 }
 
               /* Move the remainder to the beginning of the next 
@@ -1482,23 +1530,21 @@ format_entry (char *name, size_t name_len, char *desc, size_t desc_len,
             }
 
           line_out[offset_out++] = '\n';
-          strncat (*outstr, line_out, offset_out);
+          strncat (outstr, line_out, offset_out);
           column = offset_out = 0;
           goto rescan;
         }
-
       line_out[offset_out++] = c;
     }
 
-  saved_errno = errno;
-
   if (desc_len <= 2)
-    strncat (*outstr, "\n", 1);
+    strncat (outstr, "\n", 1);
 
   if (offset_out)
-    strncat (*outstr, line_out, offset_out);
+    strncat (outstr, line_out, offset_out);
 
-  *outstr_len = strlen (*outstr);
+  *outstr_out = outstr;
+  *outstr_len = strlen (outstr);
   return 1;
 }
 
@@ -1644,8 +1690,7 @@ reformat_new_entries (struct spec_entry *entries, int calign_cli, int align_cli,
           align = align_cli;
         }
 
-      if (maxwidth_cli == -1)
-        maxwidth = 79;
+      maxwidth = maxwidth_cli == -1 ? 79 : maxwidth_cli; 
 
       format_entry (name, name_len, desc, desc_len, calign, align, 
                     maxwidth, &entry->text, &entry->text_len);
@@ -1876,6 +1921,8 @@ main (int argc, char *argv[])
   struct spec_entry *entries_to_add = NULL;
   struct spec_entry *entries_to_add_from_file = NULL;
   int n_entries_to_add = 0;
+  struct spec_entry *default_entries_to_add = NULL;
+  int n_default_entries_to_add = 0;
 
   /* Record the old text of the dir file, as plain characters,
      as lines, and as nodes.  */
@@ -1906,6 +1953,12 @@ main (int argc, char *argv[])
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
 
+  /* Make sure standard input can be freopened at will.  Otherwise,
+     when stdin starts off closed, bad things could happen if a plain fopen
+     returns stdin before open_possibly_compressed_file freopens it.  */
+  if (! freopen (NULL_DEVICE, "r", stdin))
+    pfatal_with_name (NULL_DEVICE);
+
   munge_old_style_debian_options (argc, argv, &argc, &argv);
 
   while (1)
@@ -2060,6 +2113,7 @@ main (int argc, char *argv[])
           }
           break;
 
+	case 'E':
         case 'e':
           {
             struct spec_entry *next
@@ -2074,12 +2128,27 @@ main (int argc, char *argv[])
             next->text_len = olen;
             next->entry_sections = NULL;
             next->entry_sections_tail = NULL;
-            next->next = entries_to_add;
             next->missing_name = 0;
             next->missing_basename = 0;
             next->missing_description = 0;
-            entries_to_add = next;
-            n_entries_to_add++;
+	    if (opt == 'e')
+  	      {
+		next->next = entries_to_add;
+		entries_to_add = next;
+		n_entries_to_add++;
+	      } 
+	    else
+	      {
+	        /* Although this list is maintained, nothing is ever
+	           done with it.  So it seems no one cares about the
+	           feature.  The intended --help string was:
+ --defentry=TEXT     like --entry, but only use TEXT if an entry\n\
+                      is not present in INFO-FILE.\n\
+                   in case anyone ever wants to finish it.  */
+		next->next = default_entries_to_add;
+		default_entries_to_add = next;
+		n_default_entries_to_add++;
+	      }
           }
           break;
 
@@ -2146,6 +2215,10 @@ main (int argc, char *argv[])
           }
           break;
 
+	case 'S':
+	  default_section = optarg;
+	  break;
+
         case 's':
           {
             struct spec_section *next
@@ -2164,7 +2237,7 @@ main (int argc, char *argv[])
 License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n\
 This is free software: you are free to change and redistribute it.\n\
 There is NO WARRANTY, to the extent permitted by law.\n"),
-              "2013");
+              "2019");
           exit (EXIT_SUCCESS);
 
         case 'W':
@@ -2209,8 +2282,27 @@ There is NO WARRANTY, to the extent permitted by law.\n"),
   /* Now read in the Info dir file.  */
   if (debug_flag)
     printf ("debug: reading dir file %s\n", dirfile);
-  dir_data = readfile (dirfile, &dir_size, ensure_dirfile_exists,
-                       &opened_dirfilename, &compression_program);
+
+  if (!delete_flag)
+    {
+      dir_data = readfile (dirfile, &dir_size, ensure_dirfile_exists,
+                           &opened_dirfilename, &compression_program);
+      if (!dir_data)
+        pfatal_with_name (opened_dirfilename);
+    }
+  else
+    {
+      /* For "--remove" operation, it is not an error for the dir file
+         not to exist. */
+      dir_data = readfile (dirfile, &dir_size, NULL,
+                           &opened_dirfilename, &compression_program);
+      if (!dir_data)
+        {
+          warning (_("Could not read %s."), opened_dirfilename);
+          exit (EXIT_SUCCESS);
+        }
+    }
+
   dir_lines = findlines (dir_data, dir_size, &dir_nlines);
 
   parse_dir_file (dir_lines, dir_nlines, &dir_nodes);
@@ -2259,9 +2351,14 @@ There is NO WARRANTY, to the extent permitted by law.\n"),
      removing exactly.  */
   if (!remove_exactly)
     {
+      char *opened_infilename;
+
       if (debug_flag)
         printf ("debug: reading input file %s\n", infile);
-      input_data = readfile (infile, &input_size, NULL, NULL, NULL);
+      input_data = readfile (infile, &input_size, NULL,
+                             &opened_infilename, NULL);
+      if (!input_data)
+        pfatal_with_name (opened_infilename);
       input_lines = findlines (input_data, input_size, &input_nlines);
     }
 
@@ -2269,8 +2366,8 @@ There is NO WARRANTY, to the extent permitted by law.\n"),
                    &input_sections, &entries_to_add_from_file, delete_flag);
   if (!delete_flag)
     {
-      /* If there are no entries on the command-line at all, so we use the 
-         entries found in the Info file itself (if any). */
+      /* If there are no entries on the command-line at all, use the entries
+         found in the Info file itself (if any). */
       if (entries_to_add == NULL)
         {
           entries_to_add = entries_to_add_from_file;
@@ -2329,12 +2426,14 @@ There is NO WARRANTY, to the extent permitted by law.\n"),
             reformat_new_entries (entries_to_add, calign, align, maxwidth);
         }
 
-      /* If we got no sections, default to "Miscellaneous".  */
+      /* If we got no sections, use the --defsection value if it was
+         given, else "Miscellaneous".  */ 
       if (input_sections == NULL)
         {
           input_sections = (struct spec_section *)
             xmalloc (sizeof (struct spec_section));
-          input_sections->name = "Miscellaneous";
+          input_sections->name = default_section ? default_section
+                                                 : "Miscellaneous";
           input_sections->next = NULL;
           input_sections->missing = 1;
         }
@@ -2701,11 +2800,9 @@ compare_entries_text (const void *p1, const void *p2)
   return mbsncasecmp (text1, text2, len1 <= len2 ? len1 : len2);
 }
 
-/* Insert ENTRY into the add_entries_before vector
-   for line number LINE_NUMBER of the dir file.
-   DIR_LINES and N_ENTRIES carry information from like-named variables
-   in main.  */
-
+/* Insert ENTRY into the ADD_ENTRIES_BEFORE vector for line number LINE_NUMBER 
+   of the dir file.  DIR_LINES and N_ENTRIES carry information from like-named 
+   variables in main.  */
 void
 insert_entry_here (struct spec_entry *entry, int line_number,
                    struct line_data *dir_lines, int n_entries)
@@ -2726,8 +2823,8 @@ insert_entry_here (struct spec_entry *entry, int line_number,
   for (i = 0; i < n_entries; i++)
     if (dir_lines[line_number].add_entries_before[i] == 0
         || menu_line_lessp (entry->text, strlen (entry->text),
-                            dir_lines[line_number].add_entries_before[i]->text,
-                            strlen (dir_lines[line_number].add_entries_before[i]->text)))
+              dir_lines[line_number].add_entries_before[i]->text,
+              strlen (dir_lines[line_number].add_entries_before[i]->text)))
       break;
 
   if (i == n_entries)
