@@ -1,9 +1,6 @@
 /* system.h: system-dependent declarations; include this first.
-   $Id: system.h 6906 2016-01-01 18:33:45Z karl $
 
-   Copyright 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
-   2006, 2007, 2008, 2009, 2010, 2011, 2012, 2014, 2015, 2016
-   Free Software Foundation, Inc.
+   Copyright 1997-2019 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
