@@ -1,6 +1,7 @@
 # Unicode.pm: handle conversion to unicode.
 #
-# Copyright 2010, 2011, 2012 Free Software Foundation, Inc.
+# Copyright 2010, 2011, 2012, 2015, 2016, 2017, 2018 Free Software Foundation, 
+# Inc.
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,15 +33,23 @@ use Unicode::EastAsianWidth;
 
 require Exporter;
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-@ISA = qw(Exporter);
 
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
+use Texinfo::MiscXS;
+
+# Some extra initialization for the first time this module is loaded.
+# This could be done in a UNITCHECK block, but they were introduced in
+# Perl 5.10.
+our $module_loaded = 0;
+sub import {
+  if (!$module_loaded) {
+    Texinfo::XSLoader::override("Texinfo::Convert::Unicode::unicode_text",
+                                "Texinfo::MiscXS::unicode_text");
+    $module_loaded = 1;
+  }
+  # The usual import method.
+  goto &Exporter::import;
+}
 
-# This allows declaration       use Texinfo::Convert::Unicode ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
 %EXPORT_TAGS = ( 'all' => [ qw(
   unicode_accent
   encoded_accents
@@ -506,6 +515,7 @@ our %unicode_map = (
                'ordm'              => '00BA',
                'comma'             => '002C',
                'atchar'            => '0040',
+               'ampchar'           => '0026',
                'lbracechar'        => '007B',
                'rbracechar'        => '007D',
                'backslashchar'     => '005C',
@@ -1225,8 +1235,7 @@ sub unicode_accent($$)
   }
 }
 
-sub unicode_text($$)
-{
+sub unicode_text {
   my $text = shift;
   my $in_code = shift;
 
@@ -1238,7 +1247,7 @@ sub unicode_text($$)
     $text =~ s/'/\x{2019}/g;
     $text =~ s/`/\x{2018}/g;
   }
-  return Unicode::Normalize::NFC($text);
+  return $text;
 }
 
 # return the 8 bit, if it exists, and the unicode codepoint
@@ -1459,6 +1468,17 @@ sub string_width($)
 {
   my $string = shift;
 
+  $string =~ s/\p{InFullwidth}/\x{02}/g;
+  $string =~ s/\pM/\x{00}/g;
+  $string =~ s/\p{IsPrint}/\x{01}/g;
+  $string =~ s/\p{IsSpace}/\x{01}/g;
+  $string =~ s/[^\x{01}\x{02}]/\x{00}/g;
+
+  # This sums up the byte values of the bytes in $string, which now are
+  # all either 0, 1 or 2.  This is faster.  The original, more readable
+  # version is below.
+  return unpack("U0%32A*", $string);
+
   if (! defined($string)) {
     Carp::cluck();
   }
@@ -1565,14 +1585,5 @@ have a zero width (like composing accents) while some have a width of 2
 
 Patrice Dumas, E<lt>pertusus@free.frE<gt>
 
-=head1 COPYRIGHT AND LICENSE
-
-Copyright 2010, 2011, 2012 Free Software Foundation, Inc.
-
-This library is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 3 of the License,
-or (at your option) any later version.
-
 =cut
 
