@@ -17,27 +17,17 @@ $result_trees{'part_node_part_appendix'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'Top'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'node',
@@ -53,7 +43,7 @@ $result_trees{'part_node_part_appendix'} = [
             }
           ],
           'normalized' => 'Top',
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'line_nr' => {
           'file_name' => '',
@@ -66,27 +56,17 @@ $result_trees{'part_node_part_appendix'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'top'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'top',
@@ -170,34 +150,23 @@ $result_trees{'part_node_part_appendix'} = [
                 'args' => [
                   {
                     'contents' => [
-                      {
-                        'extra' => {
-                          'command' => {}
-                        },
-                        'parent' => {},
-                        'text' => ' ',
-                        'type' => 'empty_spaces_after_command'
-                      },
                       {
                         'parent' => {},
                         'text' => 'menu'
-                      },
-                      {
-                        'parent' => {},
-                        'text' => '
-',
-                        'type' => 'spaces_at_end'
                       }
                     ],
+                    'extra' => {
+                      'spaces_after_argument' => '
+'
+                    },
                     'parent' => {},
-                    'type' => 'misc_line_arg'
+                    'type' => 'line_arg'
                   }
                 ],
                 'cmdname' => 'end',
                 'extra' => {
-                  'command' => {},
                   'command_argument' => 'menu',
-                  'spaces_after_command' => {},
+                  'spaces_before_argument' => ' ',
                   'text_arg' => 'menu'
                 },
                 'line_nr' => {
@@ -209,8 +178,7 @@ $result_trees{'part_node_part_appendix'} = [
               }
             ],
             'extra' => {
-              'end_command' => {},
-              'spaces_after_command' => {}
+              'end_command' => {}
             },
             'line_nr' => {
               'file_name' => '',
@@ -227,10 +195,7 @@ $result_trees{'part_node_part_appendix'} = [
           }
         ],
         'extra' => {
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 0,
         'line_nr' => {
@@ -254,27 +219,17 @@ $result_trees{'part_node_part_appendix'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'Part 1'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'part',
@@ -287,10 +242,7 @@ $result_trees{'part_node_part_appendix'} = [
           }
         ],
         'extra' => {
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 0,
         'line_nr' => {
@@ -304,27 +256,17 @@ $result_trees{'part_node_part_appendix'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'chapter node'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'node',
@@ -340,7 +282,7 @@ $result_trees{'part_node_part_appendix'} = [
             }
           ],
           'normalized' => 'chapter-node',
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'line_nr' => {
           'file_name' => '',
@@ -353,27 +295,17 @@ $result_trees{'part_node_part_appendix'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'chapter'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'chapter',
@@ -387,10 +319,7 @@ $result_trees{'part_node_part_appendix'} = [
         ],
         'extra' => {
           'associated_part' => {},
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 1,
         'line_nr' => {
@@ -416,27 +345,17 @@ $result_trees{'part_node_part_appendix'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'Part Appendix'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'part',
@@ -449,10 +368,7 @@ $result_trees{'part_node_part_appendix'} = [
           }
         ],
         'extra' => {
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 0,
         'line_nr' => {
@@ -466,37 +382,24 @@ $result_trees{'part_node_part_appendix'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'Appendix'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'appendix',
         'contents' => [],
         'extra' => {
           'associated_part' => {},
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 1,
         'line_nr' => {
@@ -517,19 +420,12 @@ $result_trees{'part_node_part_appendix'} = [
   }
 ];
 $result_trees{'part_node_part_appendix'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[0];
-$result_trees{'part_node_part_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[1];
 $result_trees{'part_node_part_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'part_node_part_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'part_node_part_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'part_node_part_appendix'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[1];
-$result_trees{'part_node_part_appendix'}[0]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'part_node_part_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1];
+$result_trees{'part_node_part_appendix'}[0]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'part_node_part_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_part_appendix'}[0]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[1]{'extra'}{'node_content'};
-$result_trees{'part_node_part_appendix'}[0]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_part_appendix'}[0]{'contents'}[1]{'parent'} = $result_trees{'part_node_part_appendix'}[0];
-$result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2];
 $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'args'}[0];
 $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2];
 $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2];
 $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[0]{'extra'}{'command'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1];
@@ -544,73 +440,41 @@ $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'conte
 $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_description'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[1]{'args'}[3];
 $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[0];
 $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1];
-$result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2];
 $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[0];
 $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2];
-$result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'extra'}{'command'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1];
-$result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1];
 $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2];
-$result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[0];
 $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2];
 $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'contents'}[2]{'parent'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2];
-$result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'extra'}{'misc_content'}[0] = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'args'}[0]{'contents'}[1];
-$result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_part_appendix'}[0]{'contents'}[2]{'parent'} = $result_trees{'part_node_part_appendix'}[0];
 $result_trees{'part_node_part_appendix'}[0]{'extra'}{'element_command'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2];
 $result_trees{'part_node_part_appendix'}[0]{'extra'}{'node'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[1];
 $result_trees{'part_node_part_appendix'}[0]{'extra'}{'section'} = $result_trees{'part_node_part_appendix'}[0]{'contents'}[2];
-$result_trees{'part_node_part_appendix'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[0];
 $result_trees{'part_node_part_appendix'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[0]{'args'}[0];
-$result_trees{'part_node_part_appendix'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[0]{'args'}[0];
-$result_trees{'part_node_part_appendix'}[1]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[0]{'args'}[0];
 $result_trees{'part_node_part_appendix'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[0];
 $result_trees{'part_node_part_appendix'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[0];
-$result_trees{'part_node_part_appendix'}[1]{'contents'}[0]{'extra'}{'misc_content'}[0] = $result_trees{'part_node_part_appendix'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1];
-$result_trees{'part_node_part_appendix'}[1]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_part_appendix'}[1]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[1];
-$result_trees{'part_node_part_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[1];
 $result_trees{'part_node_part_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[1]{'args'}[0];
-$result_trees{'part_node_part_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[1]{'args'}[0];
-$result_trees{'part_node_part_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[1]{'args'}[0];
 $result_trees{'part_node_part_appendix'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[1];
-$result_trees{'part_node_part_appendix'}[1]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'part_node_part_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[1];
+$result_trees{'part_node_part_appendix'}[1]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'part_node_part_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_part_appendix'}[1]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[1]{'extra'}{'node_content'};
-$result_trees{'part_node_part_appendix'}[1]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_part_appendix'}[1]{'contents'}[1]{'parent'} = $result_trees{'part_node_part_appendix'}[1];
-$result_trees{'part_node_part_appendix'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[2];
 $result_trees{'part_node_part_appendix'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'part_node_part_appendix'}[1]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'part_node_part_appendix'}[1]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[2]{'args'}[0];
 $result_trees{'part_node_part_appendix'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[2];
 $result_trees{'part_node_part_appendix'}[1]{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[2];
 $result_trees{'part_node_part_appendix'}[1]{'contents'}[2]{'extra'}{'associated_part'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[0];
-$result_trees{'part_node_part_appendix'}[1]{'contents'}[2]{'extra'}{'misc_content'}[0] = $result_trees{'part_node_part_appendix'}[1]{'contents'}[2]{'args'}[0]{'contents'}[1];
-$result_trees{'part_node_part_appendix'}[1]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_part_appendix'}[1]{'contents'}[2]{'parent'} = $result_trees{'part_node_part_appendix'}[1];
 $result_trees{'part_node_part_appendix'}[1]{'element_prev'} = $result_trees{'part_node_part_appendix'}[0];
 $result_trees{'part_node_part_appendix'}[1]{'extra'}{'element_command'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[2];
 $result_trees{'part_node_part_appendix'}[1]{'extra'}{'node'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[1];
 $result_trees{'part_node_part_appendix'}[1]{'extra'}{'section'} = $result_trees{'part_node_part_appendix'}[1]{'contents'}[2];
-$result_trees{'part_node_part_appendix'}[2]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'part_node_part_appendix'}[2]{'contents'}[0];
 $result_trees{'part_node_part_appendix'}[2]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[2]{'contents'}[0]{'args'}[0];
-$result_trees{'part_node_part_appendix'}[2]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'part_node_part_appendix'}[2]{'contents'}[0]{'args'}[0];
-$result_trees{'part_node_part_appendix'}[2]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'part_node_part_appendix'}[2]{'contents'}[0]{'args'}[0];
 $result_trees{'part_node_part_appendix'}[2]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[2]{'contents'}[0];
 $result_trees{'part_node_part_appendix'}[2]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[2]{'contents'}[0];
-$result_trees{'part_node_part_appendix'}[2]{'contents'}[0]{'extra'}{'misc_content'}[0] = $result_trees{'part_node_part_appendix'}[2]{'contents'}[0]{'args'}[0]{'contents'}[1];
-$result_trees{'part_node_part_appendix'}[2]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'part_node_part_appendix'}[2]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_part_appendix'}[2]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[2];
-$result_trees{'part_node_part_appendix'}[2]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'part_node_part_appendix'}[2]{'contents'}[1];
 $result_trees{'part_node_part_appendix'}[2]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[2]{'contents'}[1]{'args'}[0];
-$result_trees{'part_node_part_appendix'}[2]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'part_node_part_appendix'}[2]{'contents'}[1]{'args'}[0];
-$result_trees{'part_node_part_appendix'}[2]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'part_node_part_appendix'}[2]{'contents'}[1]{'args'}[0];
 $result_trees{'part_node_part_appendix'}[2]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'part_node_part_appendix'}[2]{'contents'}[1];
 $result_trees{'part_node_part_appendix'}[2]{'contents'}[1]{'extra'}{'associated_part'} = $result_trees{'part_node_part_appendix'}[2]{'contents'}[0];
-$result_trees{'part_node_part_appendix'}[2]{'contents'}[1]{'extra'}{'misc_content'}[0] = $result_trees{'part_node_part_appendix'}[2]{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'part_node_part_appendix'}[2]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'part_node_part_appendix'}[2]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_part_appendix'}[2]{'contents'}[1]{'parent'} = $result_trees{'part_node_part_appendix'}[2];
 $result_trees{'part_node_part_appendix'}[2]{'element_prev'} = $result_trees{'part_node_part_appendix'}[1];
 $result_trees{'part_node_part_appendix'}[2]{'extra'}{'element_command'} = $result_trees{'part_node_part_appendix'}[2]{'contents'}[1];
@@ -661,9 +525,11 @@ $result_sectioning{'part_node_part_appendix'} = {
         'associated_node' => {
           'cmdname' => 'node',
           'extra' => {
-            'normalized' => 'Top'
+            'normalized' => 'Top',
+            'spaces_before_argument' => ' '
           }
-        }
+        },
+        'spaces_before_argument' => ' '
       },
       'level' => 0,
       'section_up' => {}
@@ -677,17 +543,20 @@ $result_sectioning{'part_node_part_appendix'} = {
             'associated_node' => {
               'cmdname' => 'node',
               'extra' => {
-                'normalized' => 'chapter-node'
+                'normalized' => 'chapter-node',
+                'spaces_before_argument' => ' '
               }
             },
-            'associated_part' => {}
+            'associated_part' => {},
+            'spaces_before_argument' => ' '
           },
           'level' => 1,
           'number' => 1,
           'section_up' => {},
           'toplevel_prev' => {},
           'toplevel_up' => {}
-        }
+        },
+        'spaces_before_argument' => ' '
       },
       'level' => 0,
       'section_childs' => [
@@ -702,14 +571,16 @@ $result_sectioning{'part_node_part_appendix'} = {
         'part_associated_section' => {
           'cmdname' => 'appendix',
           'extra' => {
-            'associated_part' => {}
+            'associated_part' => {},
+            'spaces_before_argument' => ' '
           },
           'level' => 1,
           'number' => 'A',
           'section_up' => {},
           'toplevel_prev' => {},
           'toplevel_up' => {}
-        }
+        },
+        'spaces_before_argument' => ' '
       },
       'level' => 0,
       'section_childs' => [
@@ -741,10 +612,13 @@ $result_nodes{'part_node_part_appendix'} = {
   'extra' => {
     'associated_section' => {
       'cmdname' => 'top',
-      'extra' => {},
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
       'level' => 0
     },
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   },
   'menu_child' => {
     'cmdname' => 'node',
@@ -754,14 +628,18 @@ $result_nodes{'part_node_part_appendix'} = {
         'extra' => {
           'associated_part' => {
             'cmdname' => 'part',
-            'extra' => {},
+            'extra' => {
+              'spaces_before_argument' => ' '
+            },
             'level' => 0
-          }
+          },
+          'spaces_before_argument' => ' '
         },
         'level' => 1,
         'number' => 1
       },
-      'normalized' => 'chapter-node'
+      'normalized' => 'chapter-node',
+      'spaces_before_argument' => ' '
     },
     'node_prev' => {},
     'node_up' => {}
@@ -773,8 +651,8 @@ $result_nodes{'part_node_part_appendix'} = {
         'end_command' => {
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'menu',
+            'spaces_before_argument' => ' ',
             'text_arg' => 'menu'
           }
         }
@@ -796,19 +674,20 @@ $result_nodes{'part_node_part_appendix'} = {
 };
 $result_nodes{'part_node_part_appendix'}{'menu_child'}{'node_prev'} = $result_nodes{'part_node_part_appendix'};
 $result_nodes{'part_node_part_appendix'}{'menu_child'}{'node_up'} = $result_nodes{'part_node_part_appendix'};
-$result_nodes{'part_node_part_appendix'}{'menus'}[0]{'extra'}{'end_command'}{'extra'}{'command'} = $result_nodes{'part_node_part_appendix'}{'menus'}[0];
 $result_nodes{'part_node_part_appendix'}{'node_next'} = $result_nodes{'part_node_part_appendix'}{'menu_child'};
 $result_nodes{'part_node_part_appendix'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'part_node_part_appendix'};
 
 $result_menus{'part_node_part_appendix'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   },
   'menu_child' => {
     'cmdname' => 'node',
     'extra' => {
-      'normalized' => 'chapter-node'
+      'normalized' => 'chapter-node',
+      'spaces_before_argument' => ' '
     },
     'menu_up' => {},
     'menu_up_hash' => {
@@ -842,9 +721,12 @@ $result_elements{'part_node_part_appendix'} = [
                     'extra' => {
                       'associated_part' => {
                         'cmdname' => 'part',
-                        'extra' => {},
+                        'extra' => {
+                          'spaces_before_argument' => ' '
+                        },
                         'level' => 0
-                      }
+                      },
+                      'spaces_before_argument' => ' '
                     },
                     'level' => 1,
                     'number' => 'A'
@@ -864,9 +746,12 @@ $result_elements{'part_node_part_appendix'} = [
               'extra' => {
                 'associated_part' => {
                   'cmdname' => 'part',
-                  'extra' => {},
+                  'extra' => {
+                    'spaces_before_argument' => ' '
+                  },
                   'level' => 0
-                }
+                },
+                'spaces_before_argument' => ' '
               },
               'level' => 1,
               'number' => 1
@@ -874,12 +759,14 @@ $result_elements{'part_node_part_appendix'} = [
             'node' => {
               'cmdname' => 'node',
               'extra' => {
-                'normalized' => 'chapter-node'
+                'normalized' => 'chapter-node',
+                'spaces_before_argument' => ' '
               },
               'menu_up' => {
                 'cmdname' => 'node',
                 'extra' => {
-                  'normalized' => 'Top'
+                  'normalized' => 'Top',
+                  'spaces_before_argument' => ' '
                 },
                 'menu_child' => {}
               },
@@ -910,7 +797,9 @@ $result_elements{'part_node_part_appendix'} = [
       },
       'element_command' => {
         'cmdname' => 'top',
-        'extra' => {},
+        'extra' => {
+          'spaces_before_argument' => ' '
+        },
         'level' => 0
       },
       'node' => {},
@@ -1006,38 +895,28 @@ $result_converted{'html'}->{'part_node_part_appendix'} = '<!DOCTYPE html PUBLIC
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
+<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
 <title>top</title>
 
 <meta name="description" content="top">
 <meta name="keywords" content="top">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
-<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
 <link href="#Top" rel="start" title="Top">
 <style type="text/css">
 <!--
 a.summary-letter {text-decoration: none}
 blockquote.indentedblock {margin-right: 0em}
-blockquote.smallindentedblock {margin-right: 0em; font-size: smaller}
-blockquote.smallquotation {font-size: smaller}
 div.display {margin-left: 3.2em}
 div.example {margin-left: 3.2em}
 div.lisp {margin-left: 3.2em}
-div.smalldisplay {margin-left: 3.2em}
-div.smallexample {margin-left: 3.2em}
-div.smalllisp {margin-left: 3.2em}
 kbd {font-style: oblique}
 pre.display {font-family: inherit}
 pre.format {font-family: inherit}
 pre.menu-comment {font-family: serif}
 pre.menu-preformatted {font-family: serif}
-pre.smalldisplay {font-family: inherit; font-size: smaller}
-pre.smallexample {font-size: smaller}
-pre.smallformat {font-family: inherit; font-size: smaller}
-pre.smalllisp {font-size: smaller}
-span.nocodebreak {white-space: nowrap}
 span.nolinebreak {white-space: nowrap}
-span.roman {font-family: serif; font-weight: normal}
+span.roman {font-family: initial; font-weight: normal}
 span.sansserif {font-family: sans-serif; font-weight: normal}
 ul.no-bullet {list-style: none}
 -->
@@ -1047,38 +926,31 @@ ul.no-bullet {list-style: none}
 </head>
 
 <body lang="en">
-<a name="Top"></a>
-<div class="header">
+<span id="Top"></span><div class="header">
 <p>
 Next: <a href="#chapter-node" accesskey="n" rel="next">chapter node</a>, Up: <a href="dir.html#Top" accesskey="u" rel="up">(dir)</a> &nbsp; </p>
 </div>
-<a name="top"></a>
-<h1 class="top">top</h1>
+<span id="top"></span><h1 class="top">top</h1>
 
 <table class="menu" border="0" cellspacing="0">
-<tr><td align="left" valign="top">&bull; <a href="#chapter-node" accesskey="1">chapter node</a>:</td><td>&nbsp;&nbsp;</td><td align="left" valign="top">
+<tr><td align="left" valign="top">&bull; <a href="#chapter-node" accesskey="1">chapter node</a></td><td>&nbsp;&nbsp;</td><td align="left" valign="top">
 </td></tr>
 </table>
 
 <hr>
-<a name="Part-1"></a>
-<div class="header">
+<span id="Part-1"></span><div class="header">
 <p>
 Previous: <a href="#Top" accesskey="p" rel="prev">Top</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
 </div>
 <h1 class="part">Part 1</h1>
 <hr>
 
-<a name="chapter-node"></a>
-<a name="chapter"></a>
-<h2 class="chapter">1 chapter</h2>
+<span id="chapter-node"></span><span id="chapter"></span><h2 class="chapter">1 chapter</h2>
 
-<a name="Part-Appendix"></a>
-<h1 class="part">Part Appendix</h1>
+<span id="Part-Appendix"></span><h1 class="part">Part Appendix</h1>
 <hr>
 
-<a name="Appendix"></a>
-<h2 class="appendix">Appendix A Appendix</h2>
+<span id="Appendix"></span><h2 class="appendix">Appendix A Appendix</h2>
 <hr>
 
 
