@@ -16,27 +16,17 @@ $result_trees{'semi_auto'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'Top'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
@@ -52,7 +42,7 @@ $result_trees{'semi_auto'} = {
           }
         ],
         'normalized' => 'Top',
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -65,27 +55,17 @@ $result_trees{'semi_auto'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'Top'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'top',
@@ -226,34 +206,23 @@ $result_trees{'semi_auto'} = {
               'args' => [
                 {
                   'contents' => [
-                    {
-                      'extra' => {
-                        'command' => {}
-                      },
-                      'parent' => {},
-                      'text' => ' ',
-                      'type' => 'empty_spaces_after_command'
-                    },
                     {
                       'parent' => {},
                       'text' => 'menu'
-                    },
-                    {
-                      'parent' => {},
-                      'text' => '
-',
-                      'type' => 'spaces_at_end'
                     }
                   ],
+                  'extra' => {
+                    'spaces_after_argument' => '
+'
+                  },
                   'parent' => {},
-                  'type' => 'misc_line_arg'
+                  'type' => 'line_arg'
                 }
               ],
               'cmdname' => 'end',
               'extra' => {
-                'command' => {},
                 'command_argument' => 'menu',
-                'spaces_after_command' => {},
+                'spaces_before_argument' => ' ',
                 'text_arg' => 'menu'
               },
               'line_nr' => {
@@ -265,8 +234,7 @@ $result_trees{'semi_auto'} = {
             }
           ],
           'extra' => {
-            'end_command' => {},
-            'spaces_after_command' => {}
+            'end_command' => {}
           },
           'line_nr' => {
             'file_name' => '',
@@ -283,10 +251,7 @@ $result_trees{'semi_auto'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 0,
       'line_nr' => {
@@ -300,27 +265,17 @@ $result_trees{'semi_auto'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'Chap1'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
@@ -336,7 +291,7 @@ $result_trees{'semi_auto'} = {
           }
         ],
         'normalized' => 'Chap1',
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -349,27 +304,17 @@ $result_trees{'semi_auto'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'Chapter 1'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'chapter',
@@ -453,34 +398,23 @@ $result_trees{'semi_auto'} = {
               'args' => [
                 {
                   'contents' => [
-                    {
-                      'extra' => {
-                        'command' => {}
-                      },
-                      'parent' => {},
-                      'text' => ' ',
-                      'type' => 'empty_spaces_after_command'
-                    },
                     {
                       'parent' => {},
                       'text' => 'menu'
-                    },
-                    {
-                      'parent' => {},
-                      'text' => '
-',
-                      'type' => 'spaces_at_end'
                     }
                   ],
+                  'extra' => {
+                    'spaces_after_argument' => '
+'
+                  },
                   'parent' => {},
-                  'type' => 'misc_line_arg'
+                  'type' => 'line_arg'
                 }
               ],
               'cmdname' => 'end',
               'extra' => {
-                'command' => {},
                 'command_argument' => 'menu',
-                'spaces_after_command' => {},
+                'spaces_before_argument' => ' ',
                 'text_arg' => 'menu'
               },
               'line_nr' => {
@@ -492,8 +426,7 @@ $result_trees{'semi_auto'} = {
             }
           ],
           'extra' => {
-            'end_command' => {},
-            'spaces_after_command' => {}
+            'end_command' => {}
           },
           'line_nr' => {
             'file_name' => '',
@@ -510,10 +443,7 @@ $result_trees{'semi_auto'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 1,
       'line_nr' => {
@@ -528,27 +458,17 @@ $result_trees{'semi_auto'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'Sec in chapter'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
@@ -564,7 +484,7 @@ $result_trees{'semi_auto'} = {
           }
         ],
         'normalized' => 'Sec-in-chapter',
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -577,27 +497,17 @@ $result_trees{'semi_auto'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'Sec in chapter'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'section',
@@ -610,10 +520,7 @@ $result_trees{'semi_auto'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 2,
       'line_nr' => {
@@ -628,60 +535,46 @@ $result_trees{'semi_auto'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'Section non auto'
             }
           ],
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         },
         {
           'contents' => [],
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         },
         {
           'contents' => [
-            {
-              'text' => ' ',
-              'type' => 'empty_spaces_before_argument'
-            },
             {
               'parent' => {},
               'text' => 'Chap1'
             }
           ],
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         },
         {
           'contents' => [
-            {
-              'text' => ' ',
-              'type' => 'empty_spaces_before_argument'
-            },
             {
               'parent' => {},
               'text' => 'Top'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+',
+            'spaces_before_argument' => ' '
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
@@ -710,7 +603,7 @@ $result_trees{'semi_auto'} = {
           }
         ],
         'normalized' => 'Section-non-auto',
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -723,36 +616,23 @@ $result_trees{'semi_auto'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'Section'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'section',
       'contents' => [],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 2,
       'line_nr' => {
@@ -767,19 +647,12 @@ $result_trees{'semi_auto'} = {
   'type' => 'document_root'
 };
 $result_trees{'semi_auto'}{'contents'}[0]{'parent'} = $result_trees{'semi_auto'};
-$result_trees{'semi_auto'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'semi_auto'}{'contents'}[1];
 $result_trees{'semi_auto'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[1]{'args'}[0];
-$result_trees{'semi_auto'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'semi_auto'}{'contents'}[1]{'args'}[0];
-$result_trees{'semi_auto'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'semi_auto'}{'contents'}[1]{'args'}[0];
 $result_trees{'semi_auto'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[1];
-$result_trees{'semi_auto'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'semi_auto'}{'contents'}[1]{'args'}[0]{'contents'}[1];
+$result_trees{'semi_auto'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'semi_auto'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'semi_auto'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'semi_auto'}{'contents'}[1]{'extra'}{'node_content'};
-$result_trees{'semi_auto'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'semi_auto'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'semi_auto'}{'contents'}[1]{'parent'} = $result_trees{'semi_auto'};
-$result_trees{'semi_auto'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'semi_auto'}{'contents'}[2];
 $result_trees{'semi_auto'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[2]{'args'}[0];
-$result_trees{'semi_auto'}{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'semi_auto'}{'contents'}[2]{'args'}[0];
-$result_trees{'semi_auto'}{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'semi_auto'}{'contents'}[2]{'args'}[0];
 $result_trees{'semi_auto'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[2];
 $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[2];
 $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'extra'}{'command'} = $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1];
@@ -804,34 +677,19 @@ $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[
 $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'extra'}{'menu_entry_description'} = $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[3];
 $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[1]{'contents'}[0];
 $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1];
-$result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[3];
 $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[0];
-$result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[0];
-$result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[0];
 $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[3];
-$result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'extra'}{'command'} = $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1];
-$result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'extra'}{'spaces_after_command'} = $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1];
 $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[3];
-$result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'contents'}[0];
 $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'semi_auto'}{'contents'}[2];
 $result_trees{'semi_auto'}{'contents'}[2]{'contents'}[2]{'parent'} = $result_trees{'semi_auto'}{'contents'}[2];
-$result_trees{'semi_auto'}{'contents'}[2]{'extra'}{'misc_content'}[0] = $result_trees{'semi_auto'}{'contents'}[2]{'args'}[0]{'contents'}[1];
-$result_trees{'semi_auto'}{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'semi_auto'}{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'semi_auto'}{'contents'}[2]{'parent'} = $result_trees{'semi_auto'};
-$result_trees{'semi_auto'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'semi_auto'}{'contents'}[3];
 $result_trees{'semi_auto'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[3]{'args'}[0];
-$result_trees{'semi_auto'}{'contents'}[3]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'semi_auto'}{'contents'}[3]{'args'}[0];
-$result_trees{'semi_auto'}{'contents'}[3]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'semi_auto'}{'contents'}[3]{'args'}[0];
 $result_trees{'semi_auto'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[3];
-$result_trees{'semi_auto'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'semi_auto'}{'contents'}[3]{'args'}[0]{'contents'}[1];
+$result_trees{'semi_auto'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'semi_auto'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'semi_auto'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'semi_auto'}{'contents'}[3]{'extra'}{'node_content'};
-$result_trees{'semi_auto'}{'contents'}[3]{'extra'}{'spaces_after_command'} = $result_trees{'semi_auto'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'semi_auto'}{'contents'}[3]{'parent'} = $result_trees{'semi_auto'};
-$result_trees{'semi_auto'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'semi_auto'}{'contents'}[4];
 $result_trees{'semi_auto'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[4]{'args'}[0];
-$result_trees{'semi_auto'}{'contents'}[4]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'semi_auto'}{'contents'}[4]{'args'}[0];
-$result_trees{'semi_auto'}{'contents'}[4]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'semi_auto'}{'contents'}[4]{'args'}[0];
 $result_trees{'semi_auto'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[4];
 $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[4];
 $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'extra'}{'command'} = $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1];
@@ -846,62 +704,36 @@ $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[1]{'args'}[
 $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_description'} = $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[1]{'args'}[3];
 $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[0];
 $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1];
-$result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[2];
 $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[2]{'args'}[0];
 $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[2];
-$result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[2]{'extra'}{'command'} = $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1];
-$result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1];
 $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[2];
-$result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'contents'}[0];
 $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[1]{'parent'} = $result_trees{'semi_auto'}{'contents'}[4];
 $result_trees{'semi_auto'}{'contents'}[4]{'contents'}[2]{'parent'} = $result_trees{'semi_auto'}{'contents'}[4];
-$result_trees{'semi_auto'}{'contents'}[4]{'extra'}{'misc_content'}[0] = $result_trees{'semi_auto'}{'contents'}[4]{'args'}[0]{'contents'}[1];
-$result_trees{'semi_auto'}{'contents'}[4]{'extra'}{'spaces_after_command'} = $result_trees{'semi_auto'}{'contents'}[4]{'args'}[0]{'contents'}[0];
 $result_trees{'semi_auto'}{'contents'}[4]{'parent'} = $result_trees{'semi_auto'};
-$result_trees{'semi_auto'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'semi_auto'}{'contents'}[5];
 $result_trees{'semi_auto'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[5]{'args'}[0];
-$result_trees{'semi_auto'}{'contents'}[5]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'semi_auto'}{'contents'}[5]{'args'}[0];
-$result_trees{'semi_auto'}{'contents'}[5]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'semi_auto'}{'contents'}[5]{'args'}[0];
 $result_trees{'semi_auto'}{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[5];
-$result_trees{'semi_auto'}{'contents'}[5]{'extra'}{'node_content'}[0] = $result_trees{'semi_auto'}{'contents'}[5]{'args'}[0]{'contents'}[1];
+$result_trees{'semi_auto'}{'contents'}[5]{'extra'}{'node_content'}[0] = $result_trees{'semi_auto'}{'contents'}[5]{'args'}[0]{'contents'}[0];
 $result_trees{'semi_auto'}{'contents'}[5]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'semi_auto'}{'contents'}[5]{'extra'}{'node_content'};
-$result_trees{'semi_auto'}{'contents'}[5]{'extra'}{'spaces_after_command'} = $result_trees{'semi_auto'}{'contents'}[5]{'args'}[0]{'contents'}[0];
 $result_trees{'semi_auto'}{'contents'}[5]{'parent'} = $result_trees{'semi_auto'};
-$result_trees{'semi_auto'}{'contents'}[6]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'semi_auto'}{'contents'}[6];
 $result_trees{'semi_auto'}{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[6]{'args'}[0];
-$result_trees{'semi_auto'}{'contents'}[6]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'semi_auto'}{'contents'}[6]{'args'}[0];
-$result_trees{'semi_auto'}{'contents'}[6]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'semi_auto'}{'contents'}[6]{'args'}[0];
 $result_trees{'semi_auto'}{'contents'}[6]{'args'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[6];
 $result_trees{'semi_auto'}{'contents'}[6]{'contents'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[6];
-$result_trees{'semi_auto'}{'contents'}[6]{'extra'}{'misc_content'}[0] = $result_trees{'semi_auto'}{'contents'}[6]{'args'}[0]{'contents'}[1];
-$result_trees{'semi_auto'}{'contents'}[6]{'extra'}{'spaces_after_command'} = $result_trees{'semi_auto'}{'contents'}[6]{'args'}[0]{'contents'}[0];
 $result_trees{'semi_auto'}{'contents'}[6]{'parent'} = $result_trees{'semi_auto'};
-$result_trees{'semi_auto'}{'contents'}[7]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'semi_auto'}{'contents'}[7];
 $result_trees{'semi_auto'}{'contents'}[7]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[7]{'args'}[0];
-$result_trees{'semi_auto'}{'contents'}[7]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'semi_auto'}{'contents'}[7]{'args'}[0];
 $result_trees{'semi_auto'}{'contents'}[7]{'args'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[7];
 $result_trees{'semi_auto'}{'contents'}[7]{'args'}[1]{'parent'} = $result_trees{'semi_auto'}{'contents'}[7];
-$result_trees{'semi_auto'}{'contents'}[7]{'args'}[2]{'contents'}[1]{'parent'} = $result_trees{'semi_auto'}{'contents'}[7]{'args'}[2];
+$result_trees{'semi_auto'}{'contents'}[7]{'args'}[2]{'contents'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[7]{'args'}[2];
 $result_trees{'semi_auto'}{'contents'}[7]{'args'}[2]{'parent'} = $result_trees{'semi_auto'}{'contents'}[7];
-$result_trees{'semi_auto'}{'contents'}[7]{'args'}[3]{'contents'}[1]{'parent'} = $result_trees{'semi_auto'}{'contents'}[7]{'args'}[3];
-$result_trees{'semi_auto'}{'contents'}[7]{'args'}[3]{'contents'}[2]{'parent'} = $result_trees{'semi_auto'}{'contents'}[7]{'args'}[3];
+$result_trees{'semi_auto'}{'contents'}[7]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[7]{'args'}[3];
 $result_trees{'semi_auto'}{'contents'}[7]{'args'}[3]{'parent'} = $result_trees{'semi_auto'}{'contents'}[7];
-$result_trees{'semi_auto'}{'contents'}[7]{'extra'}{'node_content'}[0] = $result_trees{'semi_auto'}{'contents'}[7]{'args'}[0]{'contents'}[1];
+$result_trees{'semi_auto'}{'contents'}[7]{'extra'}{'node_content'}[0] = $result_trees{'semi_auto'}{'contents'}[7]{'args'}[0]{'contents'}[0];
 $result_trees{'semi_auto'}{'contents'}[7]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'semi_auto'}{'contents'}[7]{'extra'}{'node_content'};
-$result_trees{'semi_auto'}{'contents'}[7]{'extra'}{'nodes_manuals'}[2]{'node_content'}[0] = $result_trees{'semi_auto'}{'contents'}[7]{'args'}[2]{'contents'}[1];
-$result_trees{'semi_auto'}{'contents'}[7]{'extra'}{'nodes_manuals'}[3]{'node_content'}[0] = $result_trees{'semi_auto'}{'contents'}[7]{'args'}[3]{'contents'}[1];
-$result_trees{'semi_auto'}{'contents'}[7]{'extra'}{'spaces_after_command'} = $result_trees{'semi_auto'}{'contents'}[7]{'args'}[0]{'contents'}[0];
+$result_trees{'semi_auto'}{'contents'}[7]{'extra'}{'nodes_manuals'}[2]{'node_content'}[0] = $result_trees{'semi_auto'}{'contents'}[7]{'args'}[2]{'contents'}[0];
+$result_trees{'semi_auto'}{'contents'}[7]{'extra'}{'nodes_manuals'}[3]{'node_content'}[0] = $result_trees{'semi_auto'}{'contents'}[7]{'args'}[3]{'contents'}[0];
 $result_trees{'semi_auto'}{'contents'}[7]{'parent'} = $result_trees{'semi_auto'};
-$result_trees{'semi_auto'}{'contents'}[8]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'semi_auto'}{'contents'}[8];
 $result_trees{'semi_auto'}{'contents'}[8]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[8]{'args'}[0];
-$result_trees{'semi_auto'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'semi_auto'}{'contents'}[8]{'args'}[0];
-$result_trees{'semi_auto'}{'contents'}[8]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'semi_auto'}{'contents'}[8]{'args'}[0];
 $result_trees{'semi_auto'}{'contents'}[8]{'args'}[0]{'parent'} = $result_trees{'semi_auto'}{'contents'}[8];
-$result_trees{'semi_auto'}{'contents'}[8]{'extra'}{'misc_content'}[0] = $result_trees{'semi_auto'}{'contents'}[8]{'args'}[0]{'contents'}[1];
-$result_trees{'semi_auto'}{'contents'}[8]{'extra'}{'spaces_after_command'} = $result_trees{'semi_auto'}{'contents'}[8]{'args'}[0]{'contents'}[0];
 $result_trees{'semi_auto'}{'contents'}[8]{'parent'} = $result_trees{'semi_auto'};
 
 $result_texis{'semi_auto'} = '@node Top
@@ -954,9 +786,11 @@ $result_sectioning{'semi_auto'} = {
         'associated_node' => {
           'cmdname' => 'node',
           'extra' => {
-            'normalized' => 'Top'
+            'normalized' => 'Top',
+            'spaces_before_argument' => ' '
           }
-        }
+        },
+        'spaces_before_argument' => ' '
       },
       'level' => 0,
       'section_childs' => [
@@ -966,9 +800,11 @@ $result_sectioning{'semi_auto'} = {
             'associated_node' => {
               'cmdname' => 'node',
               'extra' => {
-                'normalized' => 'Chap1'
+                'normalized' => 'Chap1',
+                'spaces_before_argument' => ' '
               }
-            }
+            },
+            'spaces_before_argument' => ' '
           },
           'level' => 1,
           'number' => 1,
@@ -979,9 +815,11 @@ $result_sectioning{'semi_auto'} = {
                 'associated_node' => {
                   'cmdname' => 'node',
                   'extra' => {
-                    'normalized' => 'Sec-in-chapter'
+                    'normalized' => 'Sec-in-chapter',
+                    'spaces_before_argument' => ' '
                   }
-                }
+                },
+                'spaces_before_argument' => ' '
               },
               'level' => 2,
               'number' => '1.1',
@@ -993,9 +831,11 @@ $result_sectioning{'semi_auto'} = {
                 'associated_node' => {
                   'cmdname' => 'node',
                   'extra' => {
-                    'normalized' => 'Section-non-auto'
+                    'normalized' => 'Section-non-auto',
+                    'spaces_before_argument' => ' '
                   }
-                }
+                },
+                'spaces_before_argument' => ' '
               },
               'level' => 2,
               'number' => '1.2',
@@ -1025,43 +865,55 @@ $result_nodes{'semi_auto'} = {
   'extra' => {
     'associated_section' => {
       'cmdname' => 'top',
-      'extra' => {},
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
       'level' => 0
     },
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   },
   'menu_child' => {
     'cmdname' => 'node',
     'extra' => {
       'associated_section' => {
         'cmdname' => 'chapter',
-        'extra' => {},
+        'extra' => {
+          'spaces_before_argument' => ' '
+        },
         'level' => 1,
         'number' => 1
       },
-      'normalized' => 'Chap1'
+      'normalized' => 'Chap1',
+      'spaces_before_argument' => ' '
     },
     'menu_child' => {
       'cmdname' => 'node',
       'extra' => {
         'associated_section' => {
           'cmdname' => 'section',
-          'extra' => {},
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
           'level' => 2,
           'number' => '1.1'
         },
-        'normalized' => 'Sec-in-chapter'
+        'normalized' => 'Sec-in-chapter',
+        'spaces_before_argument' => ' '
       },
       'node_next' => {
         'cmdname' => 'node',
         'extra' => {
           'associated_section' => {
             'cmdname' => 'section',
-            'extra' => {},
+            'extra' => {
+              'spaces_before_argument' => ' '
+            },
             'level' => 2,
             'number' => '1.2'
           },
-          'normalized' => 'Section-non-auto'
+          'normalized' => 'Section-non-auto',
+          'spaces_before_argument' => ' '
         },
         'node_prev' => {},
         'node_up' => {}
@@ -1075,8 +927,8 @@ $result_nodes{'semi_auto'} = {
           'end_command' => {
             'cmdname' => 'end',
             'extra' => {
-              'command' => {},
               'command_argument' => 'menu',
+              'spaces_before_argument' => ' ',
               'text_arg' => 'menu'
             }
           }
@@ -1094,8 +946,8 @@ $result_nodes{'semi_auto'} = {
         'end_command' => {
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'menu',
+            'spaces_before_argument' => ' ',
             'text_arg' => 'menu'
           }
         }
@@ -1118,28 +970,29 @@ $result_nodes{'semi_auto'} = {
 $result_nodes{'semi_auto'}{'menu_child'}{'menu_child'}{'node_next'}{'node_prev'} = $result_nodes{'semi_auto'}{'menu_child'};
 $result_nodes{'semi_auto'}{'menu_child'}{'menu_child'}{'node_next'}{'node_up'} = $result_nodes{'semi_auto'};
 $result_nodes{'semi_auto'}{'menu_child'}{'menu_child'}{'node_up'} = $result_nodes{'semi_auto'}{'menu_child'};
-$result_nodes{'semi_auto'}{'menu_child'}{'menus'}[0]{'extra'}{'end_command'}{'extra'}{'command'} = $result_nodes{'semi_auto'}{'menu_child'}{'menus'}[0];
 $result_nodes{'semi_auto'}{'menu_child'}{'node_next'} = $result_nodes{'semi_auto'}{'menu_child'}{'menu_child'}{'node_next'};
 $result_nodes{'semi_auto'}{'menu_child'}{'node_prev'} = $result_nodes{'semi_auto'};
 $result_nodes{'semi_auto'}{'menu_child'}{'node_up'} = $result_nodes{'semi_auto'};
-$result_nodes{'semi_auto'}{'menus'}[0]{'extra'}{'end_command'}{'extra'}{'command'} = $result_nodes{'semi_auto'}{'menus'}[0];
 $result_nodes{'semi_auto'}{'node_next'} = $result_nodes{'semi_auto'}{'menu_child'};
 $result_nodes{'semi_auto'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'semi_auto'};
 
 $result_menus{'semi_auto'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   },
   'menu_child' => {
     'cmdname' => 'node',
     'extra' => {
-      'normalized' => 'Chap1'
+      'normalized' => 'Chap1',
+      'spaces_before_argument' => ' '
     },
     'menu_child' => {
       'cmdname' => 'node',
       'extra' => {
-        'normalized' => 'Sec-in-chapter'
+        'normalized' => 'Sec-in-chapter',
+        'spaces_before_argument' => ' '
       },
       'menu_up' => {},
       'menu_up_hash' => {
@@ -1149,7 +1002,8 @@ $result_menus{'semi_auto'} = {
     'menu_next' => {
       'cmdname' => 'node',
       'extra' => {
-        'normalized' => 'Section-non-auto'
+        'normalized' => 'Section-non-auto',
+        'spaces_before_argument' => ' '
       },
       'menu_prev' => {},
       'menu_up' => {},
